@@ -6,6 +6,7 @@ import copy
 import logging
 import concurrent.futures
 import numpy as np
+import string
 from random import randint
 from pathlib import PurePath
 from datetime import date
@@ -47,16 +48,24 @@ def execute_parallel(func, args, message='running task', log=''):
 def extract_unit_test_value(unit_test_list):
     utl = copy.deepcopy(unit_test_list)
     for d in utl:
-        file = d.pop('file')
-        d["sql"] = read_sql(file=file, **d)
-        if 'mock_partition_date' in d:
-            d["sql"] = d["sql"].format(
-                partition_date=d['mock_partition_date']
-            )
+        sql_file = d.pop('file')
+        d["sql"] = extract_unit_test_sql_value(d, sql_file)
         d["cte"] = read_sql(file=d['mock_file'], **d)
-        d["file"] = file
+        d["file"] = sql_file
     return utl
 
+def extract_unit_test_sql_value(test, sql_file):
+    sql= read_sql(file=sql_file)
+    sql_parser = string.Formatter()
+    elements = sql_parser.parse(sql)
+    format_dict={}
+    for a, b, c, d in elements: 
+        if 'mock_{}'.format(b) in test :
+            format_dict[b]=test['mock_{}'.format(b)]
+        elif b in test:
+            format_dict[b]=test[b]
+    sql = sql.format(**format_dict)
+    return sql 
 
 def extract_unit_tests(batch_list=None, kwargs={}):
     """ return the list of unit test: unit test -> file, mock_file, output_table_name(opt) """
